km3pipe.srv.ClientManager
=========================

.. currentmodule:: km3pipe.srv

.. autoclass:: ClientManager

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ClientManager.__init__
      ~ClientManager.add
      ~ClientManager.broadcast
      ~ClientManager.broadcast_status
      ~ClientManager.heartbeat
      ~ClientManager.message_to
      ~ClientManager.raw_message_to
      ~ClientManager.remove
   
   

   
   
   